
kaiju's documentation
=======================

This is the Sphinx documentation for the SDSS Python product kaiju.

Contents
--------

.. toctree::
  :maxdepth: 2

  intro

  install

  api

  changelog
